#
# spec file for package python-jupyter_nbformat-doc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?suse_version} && 0%{?suse_version} != 1315
%bcond_without pdf
%else
%bcond_with pdf
%endif

%bcond_without html

%bcond_without tests

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-jupyter_nbformat-doc
Version:        4.4.0
Release:        lp151.3.2
Summary:        Documentation for python-jupyter_nbformat
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://github.com/jupyter/nbformat
Source:         https://files.pythonhosted.org/packages/source/n/nbformat/nbformat-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  %{python_module jupyter_nbformat}
%if %{with tests}
# Test Requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module testpath}
%endif
# Documentation requirements
%if %{with pdf} || %{with html}
BuildRequires:  python3-Sphinx
BuildRequires:  python3-numpydoc
%endif
%if %{with pdf}
BuildRequires:  python3-Sphinx-latex
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Provides:       %{name}-html = %{version}
Provides:       %{name}-pdf = %{version}
Obsoletes:      %{name}-html < %{version}
Obsoletes:      %{name}-pdf < %{version}
Provides:       %{python_module jupyter_nbformat-doc = %{version}}

%description
Documentation and help files for python-jupyter_nbformat.

%prep
%setup -q -n nbformat-%{version}

%build
# Build the documentation
pushd docs
%if %{with html}
make html
rm -r _build/html/.buildinfo
%endif
%if %{with pdf}
make latexpdf
%endif
popd

%install
mkdir -p %{buildroot}%{_docdir}/python-jupyter_nbformat

%if %{with pdf}
cp docs/_build/latex/*.pdf %{buildroot}%{_docdir}/python-jupyter_nbformat/
%endif

%if %{with html}
cp -r docs/_build/html %{buildroot}%{_docdir}/python-jupyter_nbformat/
%endif

%fdupes %{buildroot}%{_docdir}/python-jupyter_nbformat/

%if %{with tests}
%check
pushd scripts
%python_expand py.test-%{$python_bin_suffix} -k "not TestNotary and not SQLiteSignatureStoreTests" %{$python_sitelib}/nbformat
popd
%endif

%files
%defattr(-,root,root,-)
%doc COPYING.md
%{_docdir}/python-jupyter_nbformat/

%changelog
* Tue Feb 13 2018 toddrme2178@gmail.com
- Update url
* Tue Sep 19 2017 toddrme2178@gmail.com
- Update to 4.4.0
  * Explicitly state that metadata fields can be ignored.
  * Introduce official jupyter namespace inside metadata (``metadata.jupyter``).
  * Introduce ``source_hidden`` and ``outputs_hidden`` as official front-end
    metadata fields to indicate hiding source and outputs areas. **NB**: These
    fields should not be used to hide elements in exported formats.
  * Fix ending the redundant storage of signatures in the signature database.
  * :func:`nbformat.validate` can be set to not raise a ValidationError if
    additional properties are included.
  * Fix for errors with connecting and backing up the signature database.
  * Dict-like objects added to NotebookNode attributes are now transformed to be
    NotebookNode objects; transformation also works for `.update()`.
* Wed Apr 26 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Thu Mar 30 2017 toddrme2178@gmail.com
- Update to 4.3.0
  * A new pluggable ``SignatureStore`` class allows specifying different ways to
    record the signatures of trusted notebooks. The default is still an SQLite
    database. See :ref:`pluggable_signature_store` for more information.
  * :func:`nbformat.read` and :func:`nbformat.write` accept file paths as bytes
    as well as unicode.
  * Fix for calling :func:`nbformat.validate` on an empty dictionary.
  * Fix for running the tests where the locale makes ASCII the default encoding.
- Update to 4.2.0
  * Update nbformat spec version to 4.2, allowing JSON outputs to have any JSONable type,  not just ``object``,
    and mime-types of the form ``application/anything+json``.
  * Define basics of ``authors`` in notebook metadata.
    ``nb.metadata.authors`` shall be a list of objects with the property ``name``, a string of each author's full name.
  * Update use of traitlets API to require traitlets 4.1.
  * Support trusting notebooks on stdin with ``cat notebook | jupyter trust``
- Update to 4.1.0
  * Update nbformat spec version to 4.1, adding support for attachments on markdown and raw cells.
  * Catch errors opening trust database, falling back on ``:memory:`` if the database cannot be opened.
- Create doc subpackage
* Mon Oct 12 2015 toddrme2178@gmail.com
- update to version 4.0.1:
  * setuptools entrypoint
  * Add label to format docs for cross referencing
  * ensure `--version` output has actual version
* Mon Oct  5 2015 toddrme2178@gmail.com
- Build documentation
* Thu Aug 13 2015 toddrme2178@gmail.com
- Initial version
